Crate arcis_imports

Crate arcis_imports 

👎Deprecated since 0.6.0: Use the arcis crate instead of the arcis-imports crate. arcis-imports has been renamed to arcis.

Macros

arcis_static_panic
If this macro is ever run by the interpreter, it will produce a compile error.

Structs

ArcisEd25519Signature
ArcisMath
ArcisRNG
This struct gives access to randomness operations.
ArcisX25519Pubkey
The Arcis x25519 pubkey.
BaseField
BaseField25519
Represents integers modulo 2^255 - 19.
Enc
Encrypted data that allows to store data on chain which can only be converted by its owner.
EncData
LinearRegression
LogisticRegression
MXESigningKey
Mxe
Owner of secret data. Decrypting data owned by this owner requires participation from all nodes that comprise the MXE cluster.
Pack
A struct to pack data together so that they take less place on chain.
PackLocation
SHA3_256
SHA3_512
SecretKey
SerializedSolanaPublicKey
Shared
Owner for shared data between the owner of a public key and the MXE.
SigningKey
SolanaPublicKey
VerifyingKey

Enums

ArcisCircuit
DataSize
Number
Values that can fit into an i64 are SmallNum, others are BigNum. We store them in i128 so that the multiplications can happen without overflow.

Traits

Cipher
Trait for Shared and Mxe. Provides the .from_arcis(data) method.
Reveal
Call .reveal() to tell the compiler to reveal that piece of data. Cannot be called in conditional execution (inside if branches when the compiler does not know the branch at compile-time).

Functions

box_from_slice
Creates a Box<[T]> from a &[T] by cloning all items.
expit
Standard logistic function.
logit
Inverse of the standard logistic function.

Type Aliases

EvalValue
Possible outputs of a gate.

Attribute Macros

encrypted
Tells our arcis compiler to create encrypted instructions that mimic the rust module you wrote. Use #[instruction] to mark the functions that will be the entry points.
encrypted_library
Validates an arcis library, trying to find errors. Allows to build a library that can be used in #[encrypted] instructions.
instruction
An #[instruction]. Should be inside an #[encrypted] module.